@@ -1,7 +1,7 @@
 from django.core.validators import MinValueValidator
 from django.forms import (
     CharField,
-    FloatField,
+    FloatField, CheckboxInput,
 )
 from django.urls import reverse_lazy
 
@@ -170,6 +170,11 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
         label="Description",
         help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
     )
+    new_drive = CheckboxInput(
+        required=False,
+        label="Description",
+        help_text="Short Description e.g. Hard Drive 1 on SSD Cluster",
+    )
 
     fieldsets = (
         (
@@ -187,6 +192,7 @@ class LinuxVolumeTemplateForm(NetBoxModelForm):
                 "path",
                 "fs",
                 "description",
+                "new_drive"
             ),
         ),
     )
