@@ -31,6 +31,29 @@ class Migration(migrations.Migration):
                 "ordering": ("size", "id"),
             },
         ),
+        migrations.CreateModel(
+            name="LinuxDevice",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("drive",
+                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="drive_device",
+                                   to="netbox_storage.drive")),
+                ("device", models.CharField(max_length=255)),
+                ("size", models.FloatField()),
+                ("type", models.CharField(max_length=255)),
+                ("description", models.CharField(max_length=255)),
+            ],
+        ),
         migrations.CreateModel(
             name="Partition",
             fields=[
@@ -169,9 +192,9 @@ class Migration(migrations.Migration):
                     ),
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("partition",
-                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="partition_mounted_volume",
-                                   to="netbox_storage.partition")),
+                ("device",
+                 models.ForeignKey(on_delete=models.deletion.CASCADE, related_name="device_mounted_volume",
+                                   to="netbox_storage.LinuxDevice")),
                 ("path", models.CharField(max_length=255)),
                 ("fs",
                  models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE, related_name='fs_linux',
@@ -208,4 +231,28 @@ class Migration(migrations.Migration):
                                    to='netbox_storage.mountedvolume')),
             ],
         ),
+        migrations.CreateModel(
+            name="TemplateConfigurationLinuxVolume",
+            fields=[
+                ("created", models.DateTimeField(auto_now_add=True, null=True)),
+                ("last_updated", models.DateTimeField(auto_now=True, null=True)),
+                (
+                    "custom_field_data",
+                    models.JSONField(
+                        blank=True,
+                        default=dict,
+                        encoder=utilities.json.CustomFieldJSONEncoder
+                    ),
+                ),
+                ("id", models.BigAutoField(primary_key=True, serialize=False)),
+                ("platform",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name="platform_template_configuration",
+                                   to="dcim.platform")),
+                ("linux_volume",
+                 models.ForeignKey(blank=True, null=True, on_delete=models.deletion.CASCADE,
+                                   related_name='linux_volume_template_configuration',
+                                   to='netbox_storage.mountedvolume')),
+            ],
+        ),
     ]
