@@ -48,6 +48,8 @@ class TemplateVolumeConfig(PluginTemplateExtension):
 
         lv = LogicalVolume.objects.all()
         template_linux_volumes = TemplateConfigurationLinuxVolume.objects.filter(platform=obj)
+        for tlv in template_linux_volumes:
+            tlv.linux_volume.device.drive
 
 
         # storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
